#! /usr/lib/veetest/veetest -r
(revision "B.00.00")
(date "Fri 23/Oct/1992")
(component 0 "ROOTCONTEXT"
 (name "Dialog Box 3 Example")
 (interface
 )
 (implementation
  (locked no)
  (trigMode deg)
  (nextID 4)
  (component 0 "CONTEXT"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 3)
    (component 0 "IFTHENELSE"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 395 355)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "TOGGLE"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
     )
     (views
      (icon
       (origin 231 348)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONTEXT"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (nextID 2)
      (component 0 "CONFIRM"
       (name "DONE")
       (description 7 8
        This tiny "thread" begins running when the 
        enclosing UserObject is executed.  When the user
        acknowledges the OK/DONE button, there is nothing
        left to execute, so the thread ends.  Since there
        are not other threads running, the User Object
        is completed and will exit, removing the Show on
        Execute pop-up display.
       )
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 371 407)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (component 1 "NOTE"
       (name "Explanation")
       (interface
       )
       (implementation
        (component text 30 9
         PURPOSE:      This "dialog box" example shows how to "pop-up" a message for the
                       user to read and confirms; if the confirmation is not receivied in
                       a certain time, the message box is automatically exited and your
                       model can continue.
         
         USER INPUT REQUIRED:  Press "Run" and watch the dialog box pop up with a simulated
                       error message.  You can either press the "OK" button to confirm the
                       message, or you can wait for the box to go away automatically in 5
                       seconds.
         
         EXPLANATION:  This type of dialog box is usually used for non-fatal errors.  Like
                       lib/dialog.ex, this example contains an "Confirm(OK)" object and an
                       "Exit UserObject".  Notice there is another thread consisting of
                       the Delay and another "Exit UserObject".  When the Delay time is
                       reached, the "Exit UserObject" is executed, canceling all other
                       threads in the user object.
         
                       The "Delay" object waits for 5 seconds allows propagation to 
                       continue on through the junction to the "Exit UserObject."  The OK
                       button halts propagation until the button is pushed, allowing the
                       exit to occur.  Both the "Delay" and the "OK" objects, being
                       unconstrainded, execute first when the UserObject is activated.  
         
                       The execution will either last until the user presses the OK button
                       or until 5 seconds has elapsed.  The UserObject has a panel which
                       is configured to show on execute.  Notice that the message can be
                       moved to different locations once it is popped up.  This position
                       will be remembered, even after a get/save cycle.  (But you only
                       have 5 seconds to reposition it!)
         
        )
       )
       (views
        (icon
         (origin 335 343)
         (extent 110 25)
        )
        (detail
         (origin 25 208)
         (extent 731 295)
         (editing disabled)
        )
        (active detail)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 24 73)
       (extent 791 430)
       (panel
        (origin 67 234)
        (extent 787 402)
        (widget 0 icon
         (title off)
         (origin 437 581)
         (extent 58 37)
        )
        (widget 1 detail
         (title off)
         (origin 78 244)
         (extent 767 324)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 352 423)
       (extent 217 25)
      )
      (detail
       (origin 17 165)
       (extent 866 520)
       (configuration
       )
       (stackingOrder 0 1)
      )
      (active panel)
      (active panel)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 635 368)
     (extent 110 25)
    )
    (panel
     (origin 11 107)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 113 120)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 10 115)
     (extent 881 561)
     (configuration
      (connect D1:1 D0:1
       (Point 347 367)
       (Point 392 367)
      )
      (connect D2:0 D1:1
       (Point 460 638)
       (Point 460 465)
       (Point 210 465)
       (Point 210 367)
       (Point 228 367)
      )
      (connect D0:1 D2:0
       (Point 443 357)
       (Point 460 357)
       (Point 460 200)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active panel)
    (active panel)
   )
  )
  (component 1 "CONTEXT"
   (name "Input Error")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 5)
    (component 0 "DELAY"
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Done")
       (tag "Done")
       (lock constraints)
      )
     )
     (implementation
      (component delay 5)
     )
     (views
      (icon
      )
      (detail
       (origin 45 358)
       (extent 130 34)
      )
      (active detail)
     )
    )
    (component 1 "EXITCONTEXT"
     (name "Exit UserObject")
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 278 413)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "EXITCONTEXT"
     (name "Exit UserObject")
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 128 413)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 3 "CONFIRM"
     (name " OK ")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 261 337)
       (extent 58 37)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 4 "NOTE"
     (name "Note Pad")
     (interface
     )
     (implementation
      (component text 1 7
       This is a Simulated POP-UP Message!!!!
      )
     )
     (views
      (icon
      )
      (detail
       (origin 48 275)
       (extent 364 33)
       (editing enabled)
      )
      (active detail)
     )
    )
    (configuration
     (connect D3:1 D1:0)
     (connect D0:1 D2:0)
    )
    (ShowOnExecPanel
     (origin 235 184)
     (extent 397 147)
     (panel
      (origin 84 226)
      (extent 393 109)
      (widget 4 detail
       (title off)
       (origin 98 239)
       (extent 364 33)
       (editing enabled)
      )
      (widget 3 icon
       (title off)
       (origin 239 285)
       (extent 58 37)
      )
     )
    )
   )
   (views
    (icon
     (extent 110 0)
    )
    (detail
     (origin 18 232)
     (extent 425 227)
     (configuration
      (connect D3:1 D1:0
       (Point 321 355)
       (Point 350 355)
       (Point 350 410)
      )
      (connect D0:1 D2:0
       (Point 177 375)
       (Point 200 375)
       (Point 200 410)
      )
     )
     (stackingOrder 0 1 2 3 4)
    )
    (active detail)
   )
  )
  (component 2 "NOTE"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 5 5
     This example is provided as an
     illustration "as is", and 
     Hewlett-Packard Company makes 
     no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 495 106)
     (extent 291 99)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 3 "NOTE"
   (name "To Operate:")
   (interface
   )
   (implementation
    (component text 7 5
     Click on "Run" and wait for
     the dialog box to pop up with
     a simulated error message.
     
     You can either OK the message
     or wait for it to go away in
     5 seconds automatically.
    )
   )
   (views
    (icon
     (extent 110 0)
     (iconImage "notepad.icon")
    )
    (detail
     (origin 516 278)
     (extent 288 135)
     (editing enabled)
    )
    (active detail)
   )
  )
  (configuration
  )
 )
 (views
  (panel
   (origin 0 62)
   (extent 839 469)
   (widget 0 panel
    (title on)
    (origin 34 106)
    (extent 319 77)
    (widget 1 icon
     (title off)
     (origin 136 119)
     (extent 114 39)
     (format button)
    )
   )
   (widget 2 detail
    (title on)
    (origin 516 103)
    (extent 291 99)
    (editing disabled)
   )
   (widget 3 detail
    (title on)
    (origin 280 292)
    (extent 283 142)
    (editing disabled)
   )
  )
  (detail
   (origin 0 62)
   (extent 887 455)
   (configuration
   )
   (stackingOrder 1 2 3 0)
  )
  (active panel)
  (active panel)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
